akismet |release|
=================

.. automodule:: akismet


Documentation contents
----------------------


.. toctree::
   :caption: Installation and usage
   :maxdepth: 1

   install
   usage

.. toctree::
   :caption: API reference
   :maxdepth: 1

   sync_client
   async_client
   test_clients
   exceptions
   misc

.. toctree::
   :caption: Other documentation
   :maxdepth: 1

   testing
   changelog
   faq

.. seealso::

   `The developer documentation for the Akismet web service
   <https://akismet.com/developers/>`_ is useful for familiarizing yourself
   with the available API operations and features.
